"use client";

// src/use-checkbox-group.ts
import { useCallback, useMemo } from "react";
import { useCheckboxGroup as useReactAriaCheckboxGroup } from "@react-aria/checkbox";
import { chain, mergeProps } from "@react-aria/utils";
import { useCheckboxGroupState } from "@react-stately/checkbox";
import { filterDOMProps, useDOMRef } from "@koobiq-react/react-utils";
import { safeAriaLabel } from "@koobiq-react/shared-utils";
function useCheckboxGroup(props) {
  const {
    as,
    ref,
    children,
    label,
    value,
    name,
    defaultValue,
    isInvalid: isInvalidProp,
    validationState,
    orientation = "vertical",
    isDisabled = false,
    isReadOnly,
    isRequired,
    onValueChange,
    description,
    errorMessage,
    className,
    ...otherProps
  } = props;
  const Component = as || "div";
  const shouldFilterDOMProps = typeof Component === "string";
  const domRef = useDOMRef(ref);
  const checkboxGroupProps = useMemo(() => {
    return {
      ...otherProps,
      value,
      name,
      "aria-label": safeAriaLabel(otherProps["aria-label"], label),
      defaultValue,
      isRequired,
      isReadOnly,
      orientation,
      validationBehavior: "native",
      isInvalid: validationState === "invalid" || isInvalidProp,
      onChange: chain(props.onChange, onValueChange)
    };
  }, [
    value,
    name,
    label,
    defaultValue,
    isRequired,
    isReadOnly,
    orientation,
    onValueChange,
    isInvalidProp,
    validationState,
    otherProps["aria-label"],
    otherProps
  ]);
  const groupState = useCheckboxGroupState(checkboxGroupProps);
  const {
    labelProps,
    groupProps,
    descriptionProps,
    errorMessageProps,
    isInvalid: isAriaInvalid,
    validationErrors,
    validationDetails
  } = useReactAriaCheckboxGroup(checkboxGroupProps, groupState);
  let isInvalid = checkboxGroupProps.isInvalid || isAriaInvalid;
  const context = useMemo(
    () => ({
      isInvalid,
      isDisabled,
      groupState
    }),
    [
      isDisabled,
      isInvalid,
      groupState == null ? void 0 : groupState.value,
      groupState == null ? void 0 : groupState.isDisabled,
      groupState == null ? void 0 : groupState.isReadOnly,
      groupState == null ? void 0 : groupState.isInvalid,
      groupState == null ? void 0 : groupState.isSelected
    ]
  );
  const getGroupProps = useCallback(() => {
    return {
      ref: domRef,
      ...mergeProps(
        groupProps,
        filterDOMProps(otherProps, {
          enabled: shouldFilterDOMProps
        })
      )
    };
  }, [domRef, groupProps, otherProps]);
  const getLabelProps = useCallback(() => {
    return {
      ...labelProps
    };
  }, [labelProps]);
  const getWrapperProps = useCallback(() => {
    return {
      role: "presentation",
      "data-orientation": orientation
    };
  }, [orientation]);
  const getDescriptionProps = useCallback(
    (props2 = {}) => {
      return {
        ...props2,
        ...descriptionProps
      };
    },
    [descriptionProps]
  );
  const getErrorMessageProps = useCallback(
    (props2 = {}) => {
      return {
        ...props2,
        ...errorMessageProps
      };
    },
    [errorMessageProps]
  );
  return {
    Component,
    children,
    label,
    context,
    description,
    isInvalid,
    errorMessage: typeof errorMessage === "function" ? (
      // @ts-ignore
      errorMessage({ isInvalid, validationErrors, validationDetails })
    ) : errorMessage || (validationErrors == null ? void 0 : validationErrors.join(" ")),
    getGroupProps,
    getLabelProps,
    getWrapperProps,
    getDescriptionProps,
    getErrorMessageProps
  };
}

export {
  useCheckboxGroup
};
